//#define XERR
#include "incidence.ih"

void Incidence::refresh()
{
    for (Params &params: d_params)
    {
        if (params.d_prob < TOLERANCE)
            return;

        params.d_risk.refresh();
        params.d_mean.refresh();
        params.d_stdDev.refresh();
    }

    setTumorRisk();
}
